within ;
package GlucoseRegulation
  model glucoseEquation
    parameter Real QL =   8400 "Glucose Input Flow Rate";
    parameter Real lambda =   2470 "constant";
    parameter Real v = 139000
      "pokles na 20 % simuluje diabetes melitus 2. typu - inzulin independentni";
    parameter Real mi =   7200 "constant";
    parameter Real theta =   2.5 "Reabsorption Maximum";
    parameter Real phi =   0.51 "Threshold Glucose Concentration";
    parameter Real alpha =   7600 "Insulin Destruction Gain";
    parameter Real beta =   1430
      "pokles na 20 % simuluje diabetes melitus 1. typu - inzulin dependentni";
    Real TURind "Tissue utilization rate - insulin independent";
    Real TURdep "Tissue utilization rate - insulin dependent";
    Real RLR "Renal loss rate";
    Real x "Blood Glucose Concentration (mg/mL)";
    Real y "Blood Insulin Concentration (mU/ML)";
    parameter Real CG = 15000 "Capacitance of Glucose";
    parameter Real CI = 15000 "Capacitance of Insulin";
    Modelica.Blocks.Interfaces.RealInput GlucoseInfusion 
      annotation (Placement(transformation(extent={{-120,10},{-80,50}})));
    Modelica.Blocks.Interfaces.RealOutput xOutput 
      annotation (Placement(transformation(extent={{80,80},{100,100}})));
    Modelica.Blocks.Interfaces.RealOutput yOutput 
      annotation (Placement(transformation(extent={{80,-96},{100,-76}})));
    annotation(experiment(StartTime = 0.0, StopTime = 10, Tolerance = 1e-006), Diagram(
          graphics));
  initial equation
    x = 0.81;
    y = 0.055;
  equation
    xOutput = x;
    yOutput = y;

    TURind = lambda * x;
    TURdep = v * x * y;
    if x <= theta then
      RLR = 0;
    else
      RLR = mi * (x - theta);
    end if;
    CG * der(x) = GlucoseInfusion + QL - TURind - TURdep - RLR;
    if x <= phi then
      CI * der(y) = -alpha * y;
    else
      CI * der(y) = -alpha * y + beta * (x - phi);
    end if;
    annotation(uses(Modelica(version = "2.2.2")));
  end glucoseEquation;
  annotation (uses(Modelica(version="3.1")));
  model Regulation
    glucoseEquation glucoseEquation1
      annotation (Placement(transformation(extent={{-20,0},{0,20}})));
    Modelica.Blocks.Sources.Pulse pulse(
      width=0.25,
      period=10,
      offset=0,
      startTime=0.5,
      amplitude=1e6)
      annotation (Placement(transformation(extent={{-84,2},{-64,22}})));
    annotation (Diagram(graphics));
  equation
    connect(pulse.y, glucoseEquation1.GlucoseInfusion) annotation (Line(
        points={{-63,12},{-41.5,12},{-41.5,13},{-20,13}},
        color={0,0,127},
        smooth=Smooth.None));
  end Regulation;
end GlucoseRegulation;
